@@ -1,10 +1,8 @@
-#该脚本用于合并资源
+# 该脚本用于合并资源
 import argparse
-from  merge_res.merge_file import merge_file
-from  merge_res.merge_xml import merge_xml
-from  merge_res.merge_public import merge_public
-
-   
+from merge_res import merge_file
+from merge_res import merge_public
+from merge_res import merge_xml
 
 def main():
     parser = argparse.ArgumentParser()
@@ -15,16 +13,16 @@ def main():
     old_dir = args.old_dir
     new_dir = args.new_dir
     if args.option == 'all' or args.option is None:
-        merge_public.merge(old_dir,new_dir)
-        merge_file.merge(old_dir,new_dir)
-        merge_xml.merge(old_dir,new_dir)
+        merge_public.merge(old_dir, new_dir)
+        merge_file.merge(old_dir, new_dir)
+        merge_xml.merge(old_dir, new_dir)
     elif args.option == 'public':
-        merge_public.merge(old_dir,new_dir) 
+        merge_public.merge(old_dir, new_dir)
     elif args.option == 'xml':
-        merge_xml.merge(old_dir,new_dir) 
+        merge_xml.merge(old_dir, new_dir)
     elif args.option == 'file':
-        merge_file.merge(old_dir,new_dir)
-        
-        
+        merge_file.merge(old_dir, new_dir)
+
+
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
