@@ -1,10 +1,7 @@
-import argparse
 from lxml import etree
 import os
 #获取所有以layout或者xml开头的文件夹
 
-files = ["strings.xml","colors.xml","arrays.xml","styles.xml","dimens.xml","attrs.xml","plurals.xml","ids.xml","integers.xml","bools.xml","drawables.xml"]
-
 def merge(old_dir,new_dir):
     files = os.listdir(old_dir+"/res/values")
     for file in files:
